@@ -19,6 +19,7 @@ import time
 from typing import TYPE_CHECKING
 
 from .formation_algorithm import FormationAlgorithm
+from .util import rgb2hex
 
 if TYPE_CHECKING:
     from .platooning_vehicle import PlatooningVehicle  # noqa 401
@@ -32,7 +33,7 @@ def record_general_data_begin(basename: str, simulator: 'Simulator'):
     assert isinstance(simulator, Simulator)
     with open(f'{basename}_general.out', 'w') as f:
         f.write(f"simulation start: {time.asctime(time.localtime(time.time()))}\n")
-        f.write(f"parameters {str(simulator)}\n")
+        f.write(f"parameters {dict(sorted(vars(simulator).items()))}\n")
 
 
 def record_general_data_end(basename: str, simulator: 'Simulator'):
@@ -56,6 +57,7 @@ def initialize_vehicle_trips(basename: str):
             "departLane,"
             "departPos,"
             "departSpeed,"
+            "departDelay,"
             "arrival,"
             "arrivalLane,"
             "arrivalPos,"
@@ -75,7 +77,8 @@ def initialize_vehicle_trips(basename: str):
 def record_vehicle_trip(
     basename: str,
     vehicle: 'Vehicle',
-    time_loss: float,
+    depart_delay: int,
+    time_loss: int,
     expected_travel_time: float,
     travel_time_ratio: float,
     average_driving_speed: float,
@@ -88,12 +91,13 @@ def record_vehicle_trip(
         f.write(
             f"{vehicle._vid},"
             f"{vehicle._vehicle_type.name},"
-            "HBEFA3/PC_G_EU4,"  # TODO make parameter
+            f"{vehicle._vehicle_type.emission_class.name},"
             f"{vehicle.__class__.__name__},"
             f"{vehicle._depart_time},"
             f"{vehicle._depart_lane},"
             f"{vehicle._depart_position},"
             f"{vehicle._depart_speed},"
+            f"{vehicle._depart_delay},"
             f"{vehicle._simulator.step},"
             f"{vehicle._lane},"
             f"{vehicle._position},"
@@ -355,7 +359,8 @@ def initialize_vehicle_traces(basename: str):
             "routeLength,"
             "desiredSpeed,"
             "cfTargetSpeed,"
-            "cfModel"
+            "cfModel,"
+            "color"
             "\n"
         )
 
@@ -376,7 +381,8 @@ def record_vehicle_trace(basename: str, step: int, vehicle: 'Vehicle'):
             f"{vehicle.travel_distance},"
             f"{vehicle.desired_speed},"  # use potential other desired driving speed
             f"{vehicle._cf_target_speed},"
-            f"{vehicle._cf_model.name}"
+            f"{vehicle._cf_model.name},"
+            f"{rgb2hex(vehicle._color)}"
             "\n"
         )
 
