@@ -64,7 +64,9 @@ class Vehicle:
             depart_lane: int,
             depart_speed: float,
             depart_time: int,
+            depart_delay: int,
             communication_range: int,
+            pre_filled: bool = False,
     ):
         """
         Initializes a vehicle instance.
@@ -89,8 +91,12 @@ class Vehicle:
             The depart speed of the vehicle
         depart_time : int
             The depart time of the vehicle
+        depart_delay : int
+            The time the vehicle had to wait before starting its trip
         communication_range : int
             The maximum communication range of the vehicle
+        pre_filled : bool
+            Whether this vehicle was pre-filled
         """
 
         self._simulator = simulator  # the simulator
@@ -105,6 +111,8 @@ class Vehicle:
         self._depart_lane = depart_lane  # the departure lane of the vehicle
         self._depart_speed = depart_speed  # the departure speed of the vehicle
         self._depart_time = depart_time  # the departure time of the vehicle
+        self._depart_delay = depart_delay  # the depart delay of the vehicle
+        self._pre_filled = pre_filled  # whether this vehicle was pre-filled
         # vehicle details
         self._position = self._depart_position  # the current position of the vehicle
         self._lane = self._depart_lane  # the current lane of the vehicle
@@ -119,6 +127,7 @@ class Vehicle:
         self._communication_range = communication_range  # the maximum communication range between two vehicles
 
         # statistics
+        self._time_loss = 0
         self._emissions = {
             'CO': 0,  # the total CO (Kohlenmonoxid) emission in mg
             'CO2': 0,  # the total CO2 (Kohlendioxid) emission in mg
@@ -272,7 +281,7 @@ class Vehicle:
         """Returns the current rear position of the vehicle."""
 
         position = self._position - self._vehicle_type._length
-        assert(position >= 0)
+        assert position >= 0
         return position
 
     @property
@@ -373,6 +382,11 @@ class Vehicle:
             # we do not record statistics for pre-filled vehicles
             return
 
+        # calculate time loss
+        # SUMO: "The time lost due to driving below the ideal speed."
+        if self._speed < self._desired_speed:
+            self._time_loss += self._simulator.step_length
+
         if self._simulator._record_vehicle_traces:
             # mobility/trip statistics
             record_vehicle_trace(basename=self._simulator._result_base_filename, step=self._simulator.step, vehicle=self)
@@ -457,15 +471,14 @@ class Vehicle:
             return
 
         expected_travel_time = (self._arrival_position - self._depart_position) / self._desired_speed  # use explicit individual desired speed
-        assert(self.travel_time != 0)
-        time_loss = self.travel_time - self._depart_time
-        assert(expected_travel_time != 0)
+        assert self.travel_time != 0
+        assert expected_travel_time != 0
         travel_time_ratio = self.travel_time / expected_travel_time
         # NOTE: this also contains teleports
         average_driving_speed = self.travel_distance / self.travel_time
         average_deviation_desired_speed = average_driving_speed - self._desired_speed  # use explicit individual desired speed
 
-        LOG.info(f"{self._vid} arrived at {self._position}m,{self._lane} with {self._speed}m/s, took {self.travel_time}s, {self.travel_distance}m, loss: {time_loss}s, {travel_time_ratio * 100}% of expected duration")
+        LOG.info(f"{self._vid} arrived at {self._position}m,{self._lane} with {self._speed}m/s, took {self.travel_time}s, {self.travel_distance}m, loss: {self._time_loss}s, {travel_time_ratio * 100}% of expected duration")
 
         # statistic recording
 
@@ -483,8 +496,8 @@ class Vehicle:
             return
         # we could still have pre-filled vehicles that drove at least for the minimum trip length
 
-        assert(travel_time_ratio >= 0)
-        assert(average_driving_speed >= 0)
+        assert travel_time_ratio >= 0
+        assert average_driving_speed >= 0
 
         if self._simulator._record_end_trace:
             # call trace recording once again
@@ -494,7 +507,8 @@ class Vehicle:
             record_vehicle_trip(
                 basename=self._simulator._result_base_filename,
                 vehicle=self,
-                time_loss=time_loss,
+                time_loss=self._time_loss,
+                depart_delay=self._depart_delay,
                 expected_travel_time=expected_travel_time,
                 travel_time_ratio=travel_time_ratio,
                 average_driving_speed=average_driving_speed,
